pub fn run_config_probe(
state: &mut RuntimeConfigState,
probe: &dyn ConfigProbe,
request: &ConfigProbeRequest,
)Expand description
Executes one config probe, applying any emitted layer and recording its report.
pub fn run_config_probe(
state: &mut RuntimeConfigState,
probe: &dyn ConfigProbe,
request: &ConfigProbeRequest,
)Executes one config probe, applying any emitted layer and recording its report.