pub struct ConfigLoadOptions {
pub roots: ConfigRoots,
pub read_files: bool,
pub single_file: Option<PathBuf>,
pub site_sources: Vec<Symbol>,
}Expand description
Source-selection options for runtime configuration discovery.
Fields
roots: ConfigRootsHome and working config roots.
read_files: boolWhether filesystem config roots should be read.
single_file: Option<PathBuf>Explicit shared config file to read after root files.
site_sources: Vec<Symbol>Site exports that return config Dir expressions when called with
config/dir.
Implementations
Sourceimpl ConfigLoadOptions
impl ConfigLoadOptions
Sourcepub fn with_roots(roots: ConfigRoots) -> Self
pub fn with_roots(roots: ConfigRoots) -> Self
Builds options from explicit roots.